<?php

namespace GeminiLabs\SiteReviews\Addon\Authors;

use GeminiLabs\SiteReviews\Addons\Addon;
use GeminiLabs\SiteReviews\Review;

final class Application extends Addon
{
    public const ID = 'site-reviews-authors';
    public const LICENSED = true;
    public const NAME = 'Review Authors';
    public const SLUG = 'authors';

    public function canDeleteOnFrontend(Review $review): bool
    {
        if (!$review->isValid()) {
            return false; // invalid review
        }
        if (!$this->option('delete_reviews', false, 'bool')) {
            return false; // deleting is disabled
        }
        $canDelete = false;
        $user = wp_get_current_user();
        $roles = $this->option('delete_roles', [], 'array');
        $hasRole = !empty(array_intersect($roles, (array) $user->roles));
        if (!$hasRole) {
            $canDelete = false; // user role not allowed
        } elseif ($user->ID === $review->author_id) {
            $canDelete = true; // is review author
        } elseif (glsr()->can('delete_post', $review->ID)) {
            $canDelete = true; // has "delete_site-reviews" capability
        }
        return glsr(static::ID)->filterBool('can/delete', $canDelete, $review, $hasRole);
    }

    public function canEditOnFrontend(Review $review): bool
    {
        if (!$review->isValid()) {
            return false; // invalid review
        }
        if (!$this->option('edit_reviews', false, 'bool')) {
            return false; // editing is disabled
        }
        $canEdit = false;
        $user = wp_get_current_user();
        $roles = $this->option('roles', [], 'array');
        $hasRole = !empty(array_intersect($roles, (array) $user->roles));
        if (!$hasRole) {
            $canEdit = false; // user role not allowed
        } elseif ($user->ID === $review->author_id) {
            $canEdit = true; // is review author
        } elseif (glsr()->can('edit_post', $review->ID)) {
            $canEdit = true; // has "edit_site-reviews" capability
        }
        return glsr(static::ID)->filterBool('can/edit', $canEdit, $review, $hasRole);
    }

    public function canRespondOnFrontend(Review $review): bool
    {
        if (!$review->isValid()) {
            return false; // invalid review
        }
        if (!$this->option('respond_to_reviews', false, 'bool')) {
            return false; // responding is disabled
        }
        $canRespond = false;
        $user = wp_get_current_user();
        $roles = $this->option('respond_to_roles', [], 'array');
        $hasRole = !empty(array_intersect($roles, (array) $user->roles));
        if (!$hasRole) {
            $canRespond = false; // user role not allowed
        } elseif ($user->ID === $review->author_id && !in_array('administrator', (array) $user->roles)) {
            $canRespond = false; // only admin can respond to own reviews
        } elseif (glsr()->can('respond_to_post', $review->ID)) {
            $canRespond = true; // has "respond_to_site-reviews" capability
        }
        return glsr(static::ID)->filterBool('can/respond', $canRespond, $review, $hasRole);
    }
}
